@@ -1,5 +1,7 @@
 class MemcachedException(Exception):
-    pass
+    def __init__(self, message, code):
+        self.message = message
+        self.code = code
 
 
 class AuthenticationNotSupported(MemcachedException):
